@@ -1,4 +1,4 @@
-__version__ = "0.3.4"
+__version__ = "0.3.5"
 
 __release_notes__ = {
     # "0.1.6": {
@@ -21,14 +21,14 @@ __release_notes__ = {
     #
     #        ],
     #    },
-    "0.3.4": {
+    "0.3.5": {
         "STATUS": [
         ],
         "A2P2": [
         ],
         "VLTI": [
-            "Sync templates with P109",
-            "Create OB in selected folder: do not create anymore a folder but create a concatenation for SM if a Run's root is selected."
+            "Accept to add calibrator inside a Concatenation container",
+            "Use p2.iss.vltitype preference keys to set supported value of instrument's acquisition templates. ( run 'a2p2 -c' )"
         ],
         "CHARA": [
 
@@ -48,6 +48,22 @@ __release_notes__ = {
             "Try to read OB in P2 and send them back to Aspro2 as a new obs",
         ],
     },
+    "0.3.4": {
+        "STATUS": [
+        ],
+        "A2P2": [
+        ],
+        "VLTI": [
+            "Sync templates with P109",
+            "Create OB in selected folder: do not create anymore a folder but create a concatenation for SM if a Run's root is selected."
+        ],
+        "CHARA": [
+        ],
+        "TODO-SCIENCE": [
+        ],
+        "TODO-DEV": [
+        ],
+    },
     "0.3.3": {
         "STATUS": [
         ],
