@@ -50,17 +50,8 @@ class VltiInstrument(Instrument):
         if p2container.isRoot() and self.facility.isTutorialAccount():
             folderName += "_" + self.facility.a2p2client.preferences.getP2UserCommentName()
 
-
-# seems no more useful because we always create a concatenation or folder below
-        """
-        # force a top folder in demo.
-        if p2container.isRoot() and self.facility.isTutorialAccount():
-            ui.addToLog(
-                "create pre folder (required for tutorial account) ", False)
-            folder, _ = api.createFolder(p2container.containerId, folderName)
-            p2container.containerId = folder['containerId']
-            """
-
+        # do create a folder or concatenation only for SM or tutorial account
+        # should we create a concatenation only if we have multiple objects
         if p2container.isRoot():
             # create a concatenation if service mode (even if we do not have any cal at this stage)
             if p2container.isServiceModeRun():
@@ -138,6 +129,14 @@ class VltiInstrument(Instrument):
             raise ValueError(
                 "Can't detect Interferometric Array type from given baseline : %s)" % (baseline))
 
+    def checkIssVltiType(self, acqTSF):
+        # TODO improve handling of this keyword using input from Aspro2's OB
+        psection="p2.iss.vltitype"
+        vltitypePref=[v for v in self.facility.a2p2client.preferences.getConfigKeys(psection) if self.isInRange(acqTSF.tpl, "ISS.VLTITYPE", v) ]
+        if vltitypePref:
+            self.ui.addToLog(f"Using {psection} preference value : '{vltitypePref}'")
+            acqTSF.ISS_VLTITYPE = vltitypePref
+
     def getA2p2Comments(self):
         return 'Generated by ' + self.facility.a2p2client.preferences.getP2UserCommentName() + \
                ' using ASPRO 2 (c) JMMC on ' + \
